@@ -1,6 +1,7 @@
 import io
 import os
 import pickle
+import shutil
 import time
 import typing
 
@@ -10,6 +11,37 @@ import pandas as pd
 from .data_struc_kit import sum_list
 
 
+def split_file_nparts(
+        filepath: os.PathLike,
+        expected_nparts: int = 10,
+        required_part_idx: tuple = None,
+        start_pos: int = 0,
+        openmode: str = 'r',
+        writemode: str = 'w',
+        identifier_pos: str = 'before_suffix',
+):
+    dir_name = os.path.dirname(filepath)
+    basename, suffix = os.path.splitext(os.path.basename(filepath))
+    with open(filepath, openmode) as f:
+        size = f.seek(0, 2)
+        part_size = int(np.ceil(size / expected_nparts))
+        curr_pos = start_pos
+        f.seek(curr_pos)
+        for idx, end in enumerate([*list(range(part_size, size, part_size)), size], 1):
+            if required_part_idx is not None and idx not in required_part_idx:
+                continue
+            if identifier_pos == 'before_suffix':
+                new_file = os.path.join(dir_name, f'{basename}-Part{idx}_{end}.{suffix}')
+            elif identifier_pos == 'after_file':
+                new_file = f'{filepath}-Part{idx}_{end}'
+            else:
+                raise ValueError
+            with open(new_file, writemode) as f2:
+                while curr_pos <= end:
+                    f2.write(f.readline())
+                    curr_pos = f.tell()
+
+
 def adjust_file_block_pos(
         f: io.TextIOWrapper,
         start_pos: int,
@@ -70,6 +102,59 @@ def split_file_block(
     return pos_list
 
 
+def recursive_copy(original, target, ignored_items=None, verbose=True, exist_ok=True):
+    if ignored_items is None:
+        ignored_items = []
+
+    os.makedirs(target, exist_ok=exist_ok)
+    curr_items = os.listdir(original)
+    for item in curr_items:
+        if item in ignored_items:
+            continue
+        original_item_path = os.path.join(original, item)
+        target_item_path = os.path.join(target, item)
+        if os.path.isdir(original_item_path):
+            recursive_copy(original_item_path, target_item_path, ignored_items=ignored_items, verbose=verbose)
+        elif os.path.isfile(original_item_path):
+            if verbose:
+                print(f'copying {item} from {original_item_path} to {target_item_path}')
+            shutil.copy(original_item_path, target_item_path)
+        else:
+            raise
+    return 0
+
+
+def get_workspace(level=0):
+    curr_dir = os.path.abspath('.')
+    work_dir = curr_dir
+    for i in range(level):
+        work_dir = os.path.dirname(work_dir)
+    return work_dir
+
+
+def list_dir_with_identification(
+        dirname,
+        identification=None,
+        position='end',
+        regex=False,
+        full_path=False
+):
+    dir_content_list = os.listdir(dirname)
+    if identification:
+        if position == 'end':
+            dir_content_list = [
+                _ for _ in dir_content_list if _.endswith(identification)]
+        elif position == 'in':
+            dir_content_list = [
+                _ for _ in dir_content_list if identification in _]
+        else:
+            raise NameError('parameter position is illegal')
+    if not full_path:
+        return dir_content_list
+    else:
+        return [os.path.join(dirname, _) for _ in dir_content_list]
+
+
 def file_prefix_time(with_dash=False):
     curr_time = time.strftime('%Y%m%d', time.localtime())
     prefix = curr_time + '-' if with_dash else curr_time
@@ -105,6 +190,10 @@ def flatten_two_headers_file(
         method=None
 ) -> pd.DataFrame:
     """
+    :param file: path of file, or file text in string format, or list of lines
+    :param header_num:
+    :param sep:
+    :param method:
 
     method: stack headers or cross-insert or lower-first
 
@@ -127,7 +216,7 @@ def flatten_two_headers_file(
 
     """
     if isinstance(file, str):
-        if len(file) < 300 and os.path.exists(file):
+        if len(file) < 500 and os.path.exists(file):
             with open(file, 'r') as f:
                 file = f.readlines()
         else:
@@ -203,6 +292,7 @@ def check_path(
         raise_error: bool = False,
         verbose: bool = False
 ):
+    # TODO this file, or this dir
     if shown_path_right_idx is None:
         shown_filepath = path
     elif isinstance(shown_path_right_idx, int):
@@ -225,7 +315,7 @@ def check_path(
         print(f'{os.path.exists(path)} - {shown_filepath}')
 
 
-def check_path_in_dict(path_dict: dict, shown_filename_right_idx: int = None):
+def check_path_in_dict(path_dict: dict, shown_filename_right_idx: int = 1):
     # TODO 显示的文件名称可以是多个 idx 对应 substring 的组合
     """
     :param path_dict:
@@ -233,16 +323,8 @@ def check_path_in_dict(path_dict: dict, shown_filename_right_idx: int = None):
     """
     print(f'Total {len(path_dict)} files')
     for name, path in path_dict.items():
-        if shown_filename_right_idx is None or (isinstance(shown_filename_right_idx, int) and shown_filename_right_idx == 0):
-            shown_filename = path
-        elif isinstance(shown_filename_right_idx, int) and shown_filename_right_idx > 0:
-            used_path = path
-            for _ in range(shown_filename_right_idx):
-                used_path = os.path.dirname(used_path)
-            shown_filename = os.path.basename(used_path)
-        else:
-            raise ValueError(f'Param `shown_filename_right_idx` must be None or any positive integer. Now {shown_filename_right_idx}')
-        print(f'{os.path.exists(path)} - {name}: {os.path.basename(shown_filename)}')
+        check_path(path=path, name=name, shown_path_right_idx=shown_filename_right_idx,
+                   show_all_after_idx=True, raise_error=False, verbose=False)
 
 
 def check_input_df(data, *args) -> pd.DataFrame:
@@ -256,12 +338,16 @@ def check_input_df(data, *args) -> pd.DataFrame:
     return df
 
 
-def fill_path_dict(path_to_fill: str, fill_string: dict, exist_path_dict: dict = None):
+def fill_path_dict(path_to_fill: str, fill_string: dict, exist_path_dict: dict = None, max_fill_padding=None):
+    # TODO checking
     if exist_path_dict is None:
         path_dict = dict()
     else:
         path_dict = exist_path_dict.copy()
 
+    if max_fill_padding is not None:
+        explicit_fill_num = path_to_fill.count('{}')
+
     for k, file_name in fill_string.items():
         file_name = [file_name] if isinstance(file_name, str) else file_name
         path_dict[k] = path_to_fill.format(*file_name)
@@ -315,3 +401,27 @@ def data_dump_load_skip(file_path, data=None, cover_data=False, update_file=Fals
             with open(file_path, 'rb') as f:
                 data = pickle.load(f)
     return data
+
+
+def xlsx_sheets_to_text_files(
+        xlsx_path,
+        output_folder,
+        sheet_name_trans_func=lambda x: x.replace(' ', '_'),
+        skipped_row_idx=None,
+):
+    try:
+        import openpyxl
+    except ModuleNotFoundError:
+        raise ModuleNotFoundError('Need module `openpyxl` to parse xlsx file and sheets')
+
+    wb = openpyxl.open(xlsx_path)
+    for sheet_name in wb.sheetnames:
+        sheet = wb[sheet_name]
+        used_name = sheet_name_trans_func(sheet_name)
+        with open(os.path.join(output_folder, f'{used_name}.txt'), 'w') as f:
+            for row_idx, row in enumerate(sheet.iter_rows(values_only=True)):
+                if isinstance(skipped_row_idx, (tuple, list)):
+                    if row_idx in skipped_row_idx:
+                        continue
+                row = '\t'.join([(str(_) if _ is not None else '') for _ in row])
+                f.write(row + '\n')
