@@ -1,8 +1,8 @@
 import numpy as np
 
 
-def delta_tx(obse, pred, percent):
-    num_x = int(np.ceil(len(obse) * percent))
+def delta_tx(obse, pred, ratio):
+    num_x = int(np.ceil(len(obse) * ratio))
     return 2 * sorted(abs(np.array(obse) - np.array(pred)))[num_x - 1]
 
 
